@@ -3,6 +3,7 @@ from pathlib import Path
 
 import pytest
 from ape.api import Web3Provider
+from ape.types import AddressType
 
 from ape_ens.converter import ENSConversions
 
@@ -42,3 +43,9 @@ def test_is_not_convertible(converter):
     assert not converter.is_convertible("test")
     assert not converter.is_convertible("0xe1122aa5533228143C4Ce8fC4642aa33b857B332")
     assert not converter.is_convertible(23452345)
+
+
+def test_address_cache(converter):
+    new_address: AddressType = "0xe2222bb6633228143C4Ce8fC4642aa33b857B332"  # type: ignore
+    converter.address_cache["test.eth"] = new_address
+    assert converter.convert("test.eth") == new_address
